# lunr

Plugin and theme for Lunr.js

## How to use this theme

1. Install the theme

   ```python
   pip install render_engine_lunr
   ```

2. Import the theme into your project

   ```python
   from render_engine import Site
   from render_engine_lunr import Lunr

   app = Site()
   app.register_theme(Lunr)
   ```
